@@ -1,12 +1,12 @@
 package Linux::Statm::Tiny;
-$Linux::Statm::Tiny::VERSION = '0.0201';
+$Linux::Statm::Tiny::VERSION = '0.0300';
 use Moo;
 
 use Fcntl qw/ O_RDONLY /;
 use Types::Standard qw/ ArrayRef Int /;
 
 {
-    $Linux::Statm::Tiny::VERSION = '0.0201'
+    $Linux::Statm::Tiny::VERSION = '0.0300'
 }
 
 =head1 NAME
@@ -57,6 +57,23 @@ has pid => (
     default => $$,
     );
 
+=head2 C<page_size>
+
+The page size.
+
+=cut
+
+has page_size => (
+    is      => 'lazy',
+    isa     => Int,
+    default => sub {
+        my $psz = `getconf PAGE_SIZE`;
+        chomp($psz);
+        $psz;
+        },
+    init_arg => undef,
+    );
+
 =head2 C<statm>
 
 The raw array reference of values.
@@ -81,7 +98,7 @@ sub _build_statm {
 
 =head2 C<size>
 
-=head2 c<vss>
+=head2 C<vsz>
 
 Total program size, in pages.
 
@@ -121,6 +138,13 @@ my %stats = (
     lib      => 4,
     data     => 5,
     dt       => 6,
+    vsz      => 0, # alias
+    rss      => 1, # alias
+    );
+
+my %alts = (       # page_size multipliers
+    bytes    => 1,
+    kb       => 1024,
     );
 
 foreach my $attr (keys %stats) {
@@ -130,15 +154,30 @@ foreach my $attr (keys %stats) {
         default  => sub { shift->statm->[$stats{$attr}] },
         init_arg => undef,
         );
+
+    no strict 'refs';
+    *{$attr . '_pages'} = \&{$attr};
+
+    foreach my $alt (keys %alts) {
+        has "${attr}_${alt}" => (
+            is       => 'lazy',
+            isa      => Int,
+            default  => sub { my $self = shift;
+                              $self->statm->[$stats{$attr}] * $self->page_size / $alts{$alt};
+                              },
+            init_arg => undef,
+            );
+        }
+
     }
 
-sub vss {
-    shift->size(@_);
-    }
+=head1 ALIASES
 
-sub rss {
-    shift->resident(@_);
-    }
+You can append the "_pages" suffix to attributes to make it explicit
+that the return value is in pages, e.g. C<vsz_pages>.
+
+You can also use the "_bytes" or "_kb" suffixes to get the values in bytes
+or kilobytes, e.g. C<vsz_bytes> and C<vsz_kb>.
 
 =for readme continue
 
@@ -152,7 +191,7 @@ Robert Rothenberg C<< rrwo@thermeon.com >>
 
 =head1 COPYRIGHT
 
-Copyright 2014, Thermeon Worldwide, PLC.
+Copyright 2014-2015, Thermeon Worldwide, PLC.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
